@@ -17,6 +17,7 @@ sub _user_setable_attributes {
                  ID
                  currencyID
                  name
+                 signupStatus
                  taggingON
                  timezone
                  trackingON
@@ -25,7 +26,6 @@ sub _user_setable_attributes {
 
 sub _read_only_attributes {
     return ( qw/
-                 signupStatusText
            / );
 }
 
@@ -40,14 +40,14 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 See L<http://ysm.techportal.searchmarketing.yahoo.com/docs/reference/dataObjects.asp> for documentation of the various data objects.
 
 
-=head2 new
-
-Creates a new instance
-
 =cut
 
 =head1 METHODS
 
+=head2 new
+
+Creates a new instance
+
 =head2 get/set methods
 
 =over 8
@@ -55,7 +55,7 @@ Creates a new instance
     ID
     currencyID
     name
-    signupStatusText
+    signupStatus
     taggingON
     timezone
     trackingON
